Calculates weighted concordance statistics, which, depending on the chosen weighting method and tied times solution, are equivalent to several proposed methods.
For the Kaplan-Meier estimate of the training survival distribution, S, and the Kaplan-Meier estimate of the training censoring distribution, G:
weight_meth:
"I" = No weighting. (Harrell)
"GH" = Gonen and Heller's Concordance Index
"G" = Weights concordance by G^-1.
"G2" = Weights concordance by G^-2. (Uno et al.)
"SG" = Weights concordance by S/G (Shemper et al.)
"S" = Weights concordance by S (Peto and Peto)
The last three require training data.
This Measure can be instantiated via the dictionary mlr_measures or with the associated sugar function msr():
MeasureSurvCindex$new()
mlr_measures$get("surv.cindex")
msr("surv.cindex")
Type: "surv"
Range: \([0, 1]\)
Minimize: FALSE
Required prediction: crank
mlr3::Measure -> mlr3proba::MeasureSurv -> MeasureSurvCindex
cutoff(numeric(1))
Cut-off time to evaluate concordance up to.
weight_meth(numeric(1))
Method for weighting concordance.
tiex(numeric(1))
Cut-off time to evaluate concordance up to.
new()This is an abstract class that should not be constructed directly.
MeasureSurvCindex$new(
cutoff = NULL,
weight_meth = c("I", "G", "G2", "SG", "S", "GH"),
tiex = 0.5
)cutoff(numeric(1))
Cut-off time to evaluate concordance up to.
weight_meth(character(1))
Method for weighting concordance. Default "I" is Harrell's C. See details.
tiex(numeric(1))
Weighting applied to tied rankings, default is to give them half weighting.
clone()The objects of this class are cloneable with this method.
MeasureSurvCindex$clone(deep = FALSE)
deepWhether to make a deep clone.
mlr3probapeto_1972
mlr3probaharrell_1982
mlr3probagoenen_2005
mlr3probaschemper_2009
mlr3probauno_2011
Other survival measures:
mlr_measures_surv.beggC,
mlr_measures_surv.calib_alpha,
mlr_measures_surv.calib_beta,
mlr_measures_surv.chambless_auc,
mlr_measures_surv.gonenC,
mlr_measures_surv.grafSE,
mlr_measures_surv.graf,
mlr_measures_surv.harrellC,
mlr_measures_surv.hung_auc,
mlr_measures_surv.intloglossSE,
mlr_measures_surv.intlogloss,
mlr_measures_surv.loglossSE,
mlr_measures_surv.logloss,
mlr_measures_surv.maeSE,
mlr_measures_surv.mae,
mlr_measures_surv.mseSE,
mlr_measures_surv.mse,
mlr_measures_surv.nagelk_r2,
mlr_measures_surv.oquigley_r2,
mlr_measures_surv.rmseSE,
mlr_measures_surv.rmse,
mlr_measures_surv.schmid,
mlr_measures_surv.song_auc,
mlr_measures_surv.song_tnr,
mlr_measures_surv.song_tpr,
mlr_measures_surv.unoC,
mlr_measures_surv.uno_auc,
mlr_measures_surv.uno_tnr,
mlr_measures_surv.uno_tpr,
mlr_measures_surv.xu_r2