Calculates the standard error of MeasureSurvGraf.
If integrated == FALSE then the standard error of the loss, L, is approximated via,
$$se(L) = sd(L)/\sqrt{N}$$
where \(N\) are the number of observations in the test set, and \(sd\) is the standard deviation.
If integrated == TRUE then correlations between time-points need to be taken into account, therefore
$$se(L) = \sqrt{\frac{\sum_{i = 1}^M\sum_{j=1}^M \Sigma_{i,j}}{NT^2}}$$
where \(\Sigma_{i, j}\) is the sample covariance matrix over \(M\) distinct time-points.
This Measure can be instantiated via the dictionary mlr_measures or with the associated sugar function msr():
MeasureSurvGrafSE$new()
mlr_measures$get("surv.grafSE")
msr("surv.grafSE")
Type: "surv"
Range: \([0, \infty)\)
Minimize: TRUE
Required prediction: distr
mlr3::Measure -> mlr3proba::MeasureSurv -> mlr3proba::MeasureSurvIntegrated -> MeasureSurvGrafSE
new()Creates a new instance of this R6 class.
MeasureSurvGrafSE$new(integrated = TRUE, times)
integrated(logical(1))
If TRUE (default), returns the integrated score; otherwise, not integrated.
times(numeric())
If integrate == TRUE then a vector of time-points over which to integrate the score.
If integrate == FALSE then a single time point at which to return the score.
clone()The objects of this class are cloneable with this method.
MeasureSurvGrafSE$clone(deep = FALSE)
deepWhether to make a deep clone.
mlr3probagraf_1999
Other survival measures:
mlr_measures_surv.beggC,
mlr_measures_surv.calib_alpha,
mlr_measures_surv.calib_beta,
mlr_measures_surv.chambless_auc,
mlr_measures_surv.cindex,
mlr_measures_surv.gonenC,
mlr_measures_surv.graf,
mlr_measures_surv.harrellC,
mlr_measures_surv.hung_auc,
mlr_measures_surv.intloglossSE,
mlr_measures_surv.intlogloss,
mlr_measures_surv.loglossSE,
mlr_measures_surv.logloss,
mlr_measures_surv.maeSE,
mlr_measures_surv.mae,
mlr_measures_surv.mseSE,
mlr_measures_surv.mse,
mlr_measures_surv.nagelk_r2,
mlr_measures_surv.oquigley_r2,
mlr_measures_surv.rmseSE,
mlr_measures_surv.rmse,
mlr_measures_surv.schmid,
mlr_measures_surv.song_auc,
mlr_measures_surv.song_tnr,
mlr_measures_surv.song_tpr,
mlr_measures_surv.unoC,
mlr_measures_surv.uno_auc,
mlr_measures_surv.uno_tnr,
mlr_measures_surv.uno_tpr,
mlr_measures_surv.xu_r2
Other Probabilistic survival measures:
mlr_measures_surv.graf,
mlr_measures_surv.intloglossSE,
mlr_measures_surv.intlogloss,
mlr_measures_surv.loglossSE,
mlr_measures_surv.logloss,
mlr_measures_surv.schmid
Other distr survival measures:
mlr_measures_surv.calib_alpha,
mlr_measures_surv.graf,
mlr_measures_surv.intloglossSE,
mlr_measures_surv.intlogloss,
mlr_measures_surv.loglossSE,
mlr_measures_surv.logloss,
mlr_measures_surv.schmid