Calls survival::coxph().
lp is predicted by survival::predict.coxph()
distr is predicted by survival::survfit.coxph()
crank is identical to lp
This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():
LearnerSurvCoxPH$new()
mlr_learners$get("surv.coxph")
lrn("surv.coxph")
Type: "surv"
Predict Types: distr, crank, lp
Feature Types: logical, integer, numeric, factor
Properties: weights
Packages: survival distr6 pracma
mlr3::Learner -> mlr3proba::LearnerSurv -> LearnerSurvCoxPH
new()Creates a new instance of this R6 class.
LearnerSurvCoxPH$new()
clone()The objects of this class are cloneable with this method.
LearnerSurvCoxPH$clone(deep = FALSE)
deepWhether to make a deep clone.
mlr3probacox_1972
Other survival learners:
mlr_learners_surv.kaplan,
mlr_learners_surv.rpart